/// <reference types="node" />
import { EventEmitter } from 'events';
export declare type TorrentStates = 'queuing' | 'downloading' | 'seeding' | 'errored' | 'inactive' | 'paused';
export declare type TorrentProps = Partial<{
    progress: number;
    eta: number;
    name: string;
    uploadRate: number;
    downloadRate: number;
    status: TorrentStates;
    size: number;
}>;
export default abstract class Torrent<T> extends EventEmitter {
    protected opts: T;
    protected _hash: string;
    protected props: TorrentProps;
    protected live: boolean;
    constructor(opts: T, hash: string, props: TorrentProps);
    on(event: 'error', listener: () => void): this;
    on(event: 'finish', listener: () => void): this;
    on(event: 'remove', listener: () => void): this;
    on(event: 'stop', listener: () => void): this;
    on(event: 'pause', listener: () => void): this;
    on(event: 'resume', listener: () => void): this;
    on(event: 'progress', listener: (progress: number) => void): this;
    emit(event: 'error'): boolean;
    emit(event: 'finish'): boolean;
    emit(event: 'remove'): boolean;
    emit(event: 'stop'): boolean;
    emit(event: 'pause'): boolean;
    emit(event: 'resume'): boolean;
    emit(event: 'progress', progress: number): boolean;
    abstract liveFeed(polling: number): void;
    abstract update(): Promise<void>;
    abstract pause(): Promise<void>;
    abstract resume(): Promise<void>;
    abstract remove(deleteData: boolean): Promise<void>;
    readonly progress: number | undefined;
    readonly name: string | undefined;
    readonly uploadRate: number | undefined;
    readonly downloadRate: number | undefined;
    readonly status: "downloading" | "inactive" | "queuing" | "seeding" | "errored" | "paused" | undefined;
    readonly hash: string;
}
